==> manga_reader-0.0.5.tar.gz: lib/ui/page_widget.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:manga_reader/model/image_size.dart';
import 'package:manga_reader/model/page_model.dart' as pm;
import 'package:manga_reader/ui/image.dart';
import 'package:manga_reader/utils/image_utils.dart';
import 'package:manga_reader/utils/matrix4_utils.dart';
import 'package:matrix_gesture_detector/matrix_gesture_detector.dart';

class PageWidget extends StatefulWidget {
  final ValueNotifier<Matrix4> notifier = ValueNotifier(Matrix4.identity());
  final pm.Page page;

  PageWidget(this.page);

  @override
  _PageWidgetState createState() => _PageWidgetState();

}
class _PageWidgetState extends State<PageWidget> {

  final _imageKey = GlobalKey();
  final _containerKey = GlobalKey();
  double _height;
  double _width;
  double _screenWidth;
  Offset _translation = Offset(0.0, 0.0);
  Rect bounds;



  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
        future: ImageUtils.getImageSize(widget.page.url),
        builder: (BuildContext context, AsyncSnapshot<ImageSize> snapshot) {
          if (snapshot.hasData) {
            _screenWidth = MediaQuery.of(context).size.width;
            var ratio = _screenWidth / snapshot.data.width;
            _width = _screenWidth;
            _height = snapshot.data.height * ratio;
            return MatrixGestureDetector(
              shouldRotate: false,
              shouldTranslate: true,
              onMatrixUpdate: (m, tm, sm, rm) => _onMatrixUpdate(m, tm, sm),
              child: AnimatedBuilder(
                animation: widget.notifier,
                builder: (ctx, child) {
                  return Container(
                      key: _containerKey,
                      height: _height,
                      width: _width,
                      child: Stack(
                        children: [
                          AnimatedPositioned(
                            left: _translation.dx,
                            duration: Duration(milliseconds: 100),
                            child: Container(
                              child: MyImage(
                                  key: _imageKey,
                                  imageUrl: widget.page.url,
                                  height: _height,
                                  width: _width,
                                  onImageLoaded: (width, height) {}),
                            ),
                          height: _height,
                                width: _width,
                          )
                        ],
                      ));
                },
              ),
            );
          }
          return CircularProgressIndicator();
        });
  }

  _onMatrixUpdate(Matrix4 m, Matrix4 tm, Matrix4 sm) {
    widget.notifier.value = widget.notifier.value * tm;
    if (sm != Matrix4.identity()) {
      var xScale = Matrix4Utils.getXScale(sm);
      if (_width <= _screenWidth && xScale <= 1.0) {
        return;
      }
      if(xScale < 1) {
        var tmXTranslation = Matrix4Utils.getXTranslation(tm);
        widget.notifier.value.leftTranslate(tmXTranslation.abs());
      }
      _width = _imageKey.currentContext.size.width * Matrix4Utils.getYScale(sm);
      _height =
          _imageKey.currentContext.size.height * Matrix4Utils.getYScale(sm);
    }
    if (tm != Matrix4.identity()) {
      var xTranslation =  Matrix4Utils.getXTranslation(widget.notifier.value);
      print((-xTranslation + _screenWidth));
      // Going to much to le right
      var tmXTranslation = Matrix4Utils.getXTranslation(tm);
      if(!Matrix4Utils.isGoingToLeft(xTranslation) && xTranslation > 0) {
        widget.notifier.value.leftTranslate(-tmXTranslation);
      } else if(Matrix4Utils.isGoingToLeft(xTranslation) && (-xTranslation + _screenWidth) > _width) {
        widget.notifier.value.leftTranslate(tmXTranslation.abs());
      } else {
        _translation = Offset(xTranslation, 0.0);
      }
    }
  }
}

==> manga_reader-0.0.6.tar.gz: lib/ui/page_widget.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:manga_reader/model/image_size.dart';
import 'package:manga_reader/model/page_model.dart' as pm;
import 'package:manga_reader/ui/image.dart';
import 'package:manga_reader/utils/image_utils.dart';
import 'package:manga_reader/utils/matrix4_utils.dart';
import 'package:matrix_gesture_detector/matrix_gesture_detector.dart';

class PageWidget extends StatefulWidget {
  final ValueNotifier<Matrix4> notifier = ValueNotifier(Matrix4.identity());
  final pm.Page page;

  PageWidget(this.page);

  @override
  _PageWidgetState createState() => _PageWidgetState();

}
class _PageWidgetState extends State<PageWidget> {
  ValueNotifier<double> progressIndicator = ValueNotifier(0.0);
  final _imageKey = GlobalKey();
  final _containerKey = GlobalKey();
  double _height;
  double _width;
  double _screenWidth;
  Offset _translation = Offset(0.0, 0.0);
  Rect bounds;

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
        future: ImageUtils.getImageSize(
            widget.page.url,
            (cumulativeBytesLoaded, expectedTotalBytes) {
              progressIndicator.value = expectedTotalBytes != null ?
              cumulativeBytesLoaded / expectedTotalBytes
                  : 0.0;
            }
        ),
        builder: (BuildContext context, AsyncSnapshot<ImageSize> snapshot) {
          if (snapshot.hasData) {
            _screenWidth = MediaQuery.of(context).size.width;
            var ratio = _screenWidth / snapshot.data.width;
            _width = _screenWidth;
            _height = snapshot.data.height * ratio;
            return MatrixGestureDetector(
              shouldRotate: false,
              shouldTranslate: true,
              onMatrixUpdate: (m, tm, sm, rm) => _onMatrixUpdate(m, tm, sm),
              child: AnimatedBuilder(
                animation: widget.notifier,
                builder: (ctx, child) {
                  return Container(
                      key: _containerKey,
                      height: _height,
                      width: _width,
                      child: Stack(
                        children: [
                          AnimatedPositioned(
                            left: _translation.dx,
                            duration: Duration(milliseconds: 100),
                            child: Container(
                              child: MyImage(
                                  key: _imageKey,
                                  imageUrl: widget.page.url,
                                  height: _height,
                                  width: _width,
                                  onImageLoaded: (width, height) {}),
                            ),
                          height: _height,
                                width: _width,
                          )
                        ],
                      ));
                },
              ),
            );
          }
          return ValueListenableBuilder(
            valueListenable: progressIndicator,
            builder: (context, value, widget) {
              return SizedBox(
                  height: 400,
                  child: Center(
                    child: CircularProgressIndicator(
                      value: value,
                    ),
                  )
              );
            },
          );
        });
  }

  _onMatrixUpdate(Matrix4 m, Matrix4 tm, Matrix4 sm) {
    widget.notifier.value = widget.notifier.value * tm;
    if (sm != Matrix4.identity()) {
      var xScale = Matrix4Utils.getXScale(sm);
      if (_width <= _screenWidth && xScale <= 1.0) {
        return;
      }
      if(xScale < 1) {
        var tmXTranslation = Matrix4Utils.getXTranslation(tm);
        widget.notifier.value.leftTranslate(tmXTranslation.abs());
      }
      _width = _imageKey.currentContext.size.width * Matrix4Utils.getYScale(sm);
      _height =
          _imageKey.currentContext.size.height * Matrix4Utils.getYScale(sm);
    }
    if (tm != Matrix4.identity()) {
      var xTranslation =  Matrix4Utils.getXTranslation(widget.notifier.value);
      print((-xTranslation + _screenWidth));
      // Going to much to le right
      var tmXTranslation = Matrix4Utils.getXTranslation(tm);
      if(!Matrix4Utils.isGoingToLeft(xTranslation) && xTranslation > 0) {
        widget.notifier.value.leftTranslate(-tmXTranslation);
      } else if(Matrix4Utils.isGoingToLeft(xTranslation) && (-xTranslation + _screenWidth) > _width) {
        widget.notifier.value.leftTranslate(tmXTranslation.abs());
      } else {
        _translation = Offset(xTranslation, 0.0);
      }
    }
  }
}
